# SearchGooglePy

SearchGooglePy is a simple (un-official) Google Search API under python.

This page will help you to [install](#install) and get a [quick start](#quick-start)

___

**A few advertisement and credits before you start :**

***Dependencies***

- Python 3
- pip 22.2.2

***Credits***

See [ThirdPartyNotices.md](./ThirdPartyNotices.md) file to watch credits

___

## Install

To install SearchGooglePy follow the steps behavior:

### Windows:

1. Open the `Command Prompt` or `PowerShell`.
2. type on your prompt:
```powershell
pip install -m SearchGooglePy
```
